@@ -7,7 +7,8 @@ if False:
 
 class DeleteFrom(Statement):
     def __init__(self, table: Table):
-        super().__init__(table)
+        super().__init__(table.database)
+        self.table = table
         self.where_statement = None
 
     def build_sql(self) -> str:
@@ -16,6 +17,7 @@ class DeleteFrom(Statement):
 
     def where(self, where: Where | Condition) -> DeleteFrom:
         if self.where_statement is None:
+            where.register(self)
             self.where_statement = where
         else:
             self.where_statement &= where
