@@ -5,3 +5,7 @@ from .boolean import Boolean
 from .date import Date
 from .time import Time
 from .null import Null
+from .blob import Blob
+from .float import Float
+from .types import Types
+
