@@ -1,14 +1,22 @@
 from __future__ import annotations
 from .conjunctions import Conjunctions
+from ..parameterized import Parameterized
+
 if False:
     from .condition import Condition
 
 
-class Where:
+class Where(Parameterized):
     def __init__(self, *syntax: Condition | Conjunctions):
         self.syntax = ["(", *syntax, ")"]
 
-    def __str__(self) -> str:
+    @property
+    def parameters(self) -> list[object]:
+        from .condition import Condition  # TODO: Clean Up Improper Import
+        return [condition for parameters in map(lambda condition: condition.parameters, filter(
+            lambda syntax: isinstance(syntax, Condition), self.syntax)) for condition in parameters]
+
+    def build_sql(self) -> str:
         syntax = map(lambda part: part.value if isinstance(part, Conjunctions) else str(part), self.syntax)
         return " ".join(syntax).replace("( ", "(").replace(" )", ")")
 
